collet.actions.odata


compile-odata-structclj

(compile-odata-struct parser data)
(compile-odata-struct parser combine data)

Given a parser, a combine function and a data structure, it will compile the data structure into a string representation of the OData query parameters

Given a parser, a combine function and a data structure,
it will compile the data structure into a string representation of the OData query parameters
sourceraw docstring

dispatch-fnclj

(dispatch-fn x)
source

expand-parserclj

source

expand-specclj

source

filter-parserclj

source

filter-specclj

source

join-as-listclj

source

join-as-pathclj

source

make-odata-request-mapclj

(make-odata-request-map {:keys [service-url segment filter select expand order
                                top skip follow-next-link next-link
                                get-total-count]
                         :or {follow-next-link false get-total-count false}
                         $count :count})

Builds the request map for an OData request

Builds the request map for an OData request
sourceraw docstring

odata-params-specclj

source

odata-requestclj

(odata-request params prev-state)

Makes an OData request Reuses the HTTP action to make the request but formats the request according to OData specs OData specific options: :service-url, :segment, :filter, :select, :expand, :order, :top, :skip, :count, :follow-next-link, :get-total-count Also other HTTP options can be passed like :rate-limiter, :headers, :unexceptional-status, :rate, etc

Makes an OData request
Reuses the HTTP action to make the request but formats the request according to OData specs
OData specific options: :service-url, :segment, :filter, :select, :expand, :order, :top, :skip, :count, :follow-next-link, :get-total-count
Also other HTTP options can be passed like :rate-limiter, :headers, :unexceptional-status, :rate, etc
sourceraw docstring

order-by-parserclj

source

order-by-specclj

source

registryclj

source

segment-parserclj

source

segment-specclj

source

select-parserclj

source

select-specclj

source

stringifycljmultimethod

Multi-method to stringify the parsed OData parameters

Multi-method to stringify the parsed OData parameters
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries