(compile-odata-struct parser data)(compile-odata-struct parser combine data)Given a parser, a combine function and a data structure, it will compile the data structure into a string representation of the OData query parameters
Given a parser, a combine function and a data structure, it will compile the data structure into a string representation of the OData query parameters
(make-odata-request-map {:keys [service-url segment filter select expand order
top skip follow-next-link next-link
get-total-count]
:or {follow-next-link false get-total-count false}
$count :count})Builds the request map for an OData request
Builds the request map for an OData request
(odata-request params prev-state)Makes an OData request Reuses the HTTP action to make the request but formats the request according to OData specs OData specific options: :service-url, :segment, :filter, :select, :expand, :order, :top, :skip, :count, :follow-next-link, :get-total-count Also other HTTP options can be passed like :rate-limiter, :headers, :unexceptional-status, :rate, etc
Makes an OData request Reuses the HTTP action to make the request but formats the request according to OData specs OData specific options: :service-url, :segment, :filter, :select, :expand, :order, :top, :skip, :count, :follow-next-link, :get-total-count Also other HTTP options can be passed like :rate-limiter, :headers, :unexceptional-status, :rate, etc
Multi-method to stringify the parsed OData parameters
Multi-method to stringify the parsed OData parameters
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |